#
# spec file for package kubectl-operator
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kubectl-operator
Version:        0.5.1
Release:        1.1
Summary:        Manage Kubernetes Operators from the command line
License:        Apache-2.0
URL:            https://github.com/operator-framework/kubectl-operator
Source:         kubectl-operator-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.19

%description
kubectl operator is a kubectl plugin that functions as a package manager for
Operators in your cluster. It simplifies adding and removing Operator catalogs,
and it has familiar commands for installing, uninstalling, and listing
available and installed Operators.

NOTE: This plugin requires Operator Lifecycle Manager to be installed in your cluster. See the OLM installation instructions here:
https://olm.operatorframework.io/docs/getting-started/

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-s -w \
   -X github.com/operator-framework/kubectl-operator/internal/version.GitVersion=%{version} \
   -X github.com/operator-framework/kubectl-operator/internal/version.GitCommit=v%{version} \
   -X github.com/operator-framework/kubectl-operator/internal/version.GitTreeState=clean" \
   -o bin/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Tue Apr 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.5.1:
  * Bump github.com/containerd/containerd from 1.7.15 to 1.7.16
    (#148)
  * Bump github.com/onsi/gomega from 1.33.0 to 1.33.1 (#150)
  * Bump github.com/onsi/gomega from 1.32.0 to 1.33.0 (#143)
  * remove bundle injection, make golangci-lint config consistent
    (#145)
  * Bump github.com/operator-framework/operator-registry (#139)
  * update dependencies (#137)
  * update dependencies (#131)
  * GH Actions: add workflow to add epic issues to OLMv1 project
    (#121)
  * Remove timflannagan from OWNERS (#114)
  * Bump github.com/operator-framework/operator-registry (#104)
  * Bump github.com/opencontainers/image-spec from 1.1.0-rc4 to
    1.1.0-rc5 (#106)
  * Bump github.com/containerd/containerd from 1.7.6 to 1.7.12
    (#105)
  * manage tool deps with bingo (#102)
  * run CI in merge queue (#103)
  * deps: bump k8s.io to 0.28.5 and controller-runtime to 0.16.3
    (#101)
  * Bump actions/setup-go from 3 to 5 (#94)
  * Bump actions/checkout from 2 to 4 (#93)
  * deps: bump go version, operator-controller, and golangci-lint
    (#91)
  * enable dependabot (#92)
  * GH Actions CI and release improvements (#89)
* Fri Nov 17 2023 kastl@b1-systems.de
- Update to version 0.5.0:
  * list-operands: include namespace in error message when package
    is not found (#88)
  * Update to generic sets (#87)
  * OLMv1 Operator install/uninstall (#85)
  * Use package channel entries to lookup version (#76)
  * operator describe: don't panic when specified package name is
    not found (#79)
  * Fix install mode compatibility checking (#80)
  * Return only found PackageManifests (#78)
  * Bump to go 1.19 and k8s 1.25 (#77)
  * assets/demo: Use the eval built-in command for typed commands
    (#74)
  * .github: Fix the go-apidiff action and use the correct version
    (#75)
* Mon Oct 30 2023 Johannes Kastl <kastl@b1-systems.de>
- new package kubectl-operator: Manage Kubernetes Operators from
  the command line
